==> gnome-do-plugins_0.6.0.1+dfsg.orig.tar.gz: gnome-do-plugins-0.6.0.1/DiskMounter/src/DriveItemSource.cs <==
// DriveItemSource.cs
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <http://www.gnu.org/licenses/> or 
// write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
// Boston, MA 02111-1307 USA
//

using System;
using System.Collections.Generic;
using Gnome.Vfs;

using Do.Universe;

namespace DiskMounter {

	public class DriveItemSource : IItemSource {

		List<IItem> items;
		private static Gnome.Vfs.VolumeMonitor monitor;

		public DriveItemSource ()
		{
			Vfs.Initialize ();
			monitor = Gnome.Vfs.VolumeMonitor.Get ();
			items = new List<IItem> ();
		}

		public string Name {
			get { return "Drives"; }
		}

		public string Description {
			get { return "Available mounted and unmounted drives."; }
		}

		public string Icon {
			get { return "harddrive"; }
		}

		public Type[] SupportedItemTypes {
			get {
				return new Type[] {
					typeof (DriveItem),
				};
			}
		}

		public ICollection<IItem> Items {
			get { return items; }
		}

		public ICollection<IItem> ChildrenOfItem (IItem item)
		{
			return null;
		}

		public void UpdateItems ()
		{
			items.Clear ();

			foreach (Drive drive in monitor.ConnectedDrives){
				items.Add (new DriveItem (drive));              
			}
		}  
	}
}

==> gnome-do-plugins_0.8.1.3+dfsg.orig.tar.gz: gnome-do-plugins-0.8.1.3/DiskMounter/src/DriveItemSource.cs <==
// DriveItemSource.cs
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <http://www.gnu.org/licenses/> or 
// write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
// Boston, MA 02111-1307 USA
//

using System;
using System.Collections.Generic;
using Gnome.Vfs;

using Do.Universe;

namespace DiskMounter {

	public class DriveItemSource : ItemSource {

		List<Item> items;
		private static Gnome.Vfs.VolumeMonitor monitor;

		public DriveItemSource ()
		{
			Vfs.Initialize ();
			monitor = Gnome.Vfs.VolumeMonitor.Get ();
			items = new List<Item> ();
		}

		public override string Name {
			get { return "Drives"; }
		}

		public override string Description {
			get { return "Available mounted and unmounted drives."; }
		}

		public override string Icon {
			get { return "harddrive"; }
		}

		public override IEnumerable<Type> SupportedItemTypes {
			get {
				return new Type[] {
					typeof (DriveItem),
				};
			}
		}

		public override IEnumerable<Item> Items {
			get { return items; }
		}

		public override IEnumerable<Item> ChildrenOfItem (Item item)
		{
			return null;
		}

		public override void UpdateItems ()
		{
			items.Clear ();

			foreach (Drive drive in monitor.ConnectedDrives){
				items.Add (new DriveItem (drive));              
			}
		}  
	}
}
